package edu.uoc.perezdehitajesus.uocapplication;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;

import edu.uoc.perezdehitajesus.uocapplication.modelClass.MentorContent;

import java.util.List;
import java.util.Random;

public class MentorListActivity extends AppCompatActivity {

    private boolean mTwoPane;

    public Activity context = this;

    String name;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_mentor_list);

        if (findViewById(R.id.mentor_detail_container) != null) {
            mTwoPane = true;
        }

        View recyclerView = findViewById(R.id.mentor_list);
        assert recyclerView != null;
        setupRecyclerView((RecyclerView) recyclerView);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
    }

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    public boolean onOptionsItemSelected(MenuItem item) {

        int id = item.getItemId();

        if (id == R.id.faqs) {
            Intent intent = new Intent(this, FaqsActivity.class);
            this.startActivity(intent);
            return true;
        }

        if (id == R.id.help) {
            Intent i = new Intent(Intent.ACTION_SEND);
            i.setType("message/rfc822");
            i.putExtra(Intent.EXTRA_EMAIL, new String[]{ getIntent().getStringExtra("jesusperezdehita@gmail.com")});
            i.putExtra(Intent.EXTRA_SUBJECT, "Contact Support User ID"+UserInfo.getUser_id()+" User:"+UserInfo.getUser_name()+" "+UserInfo.getUser_surname());
            i.putExtra(Intent.EXTRA_TEXT, "Introdueix la pregunta o incidència que tinguis detectat i ens posarem en seguida en contacte amb tu, gràcies.");
            try {
                startActivity(Intent.createChooser(i, "Enviant el correu..."));
            } catch (android.content.ActivityNotFoundException ex) {
                Toast.makeText(MentorListActivity.this, "No tens instal·lat cap client de correu com Gmail, etc.", Toast.LENGTH_SHORT).show();
            }
        }

        if (id == R.id.closeApp) {
            Intent intent = new Intent(this, LoginActivity.class);
            this.startActivity(intent);
            finishAffinity();
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private void setupRecyclerView(@NonNull RecyclerView recyclerView) {
        recyclerView.setAdapter(new SimpleItemRecyclerViewAdapter(this, MentorContent.ITEMS, mTwoPane));
    }

    public class SimpleItemRecyclerViewAdapter extends RecyclerView.Adapter<SimpleItemRecyclerViewAdapter.ViewHolder> {
        private final MentorListActivity mParentActivity;
        private final List<MentorContent.MentorItem> mValues;
        private final boolean mTwoPane;
        private final View.OnClickListener mOnClickListener = new View.OnClickListener() {
            @Override
            public void onClick(View view) {
            MentorContent.MentorItem item = (MentorContent.MentorItem) view.getTag();
            if (mTwoPane) {
                Bundle arguments = new Bundle();
                arguments.putString(MentorDetailFragment.ARG_ITEM_ID, item.id);
                MentorDetailFragment fragment = new MentorDetailFragment();
                fragment.setArguments(arguments);
                mParentActivity.getFragmentManager().beginTransaction()
                        .replace(R.id.mentor_detail_container, fragment)
                        .commit();
            } else {
                Context context = view.getContext();
                Intent intent = new Intent(context, MentorDetailActivity.class);
                intent.putExtra(MentorDetailFragment.ARG_ITEM_ID, item.id);

                context.startActivity(intent);
            }
            }
        };

        SimpleItemRecyclerViewAdapter(MentorListActivity parent,List<MentorContent.MentorItem> items,boolean twoPane) {
            mValues = items;
            mParentActivity = parent;
            mTwoPane = twoPane;
        }

        @Override
        public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            View view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.mentor_list_content, parent, false);
            return new ViewHolder(view);
        }

        @Override
        public void onBindViewHolder(final ViewHolder holder, int position) {
            holder.mNameView.setText(mValues.get(position).name);
            holder.mSurnameView.setText(mValues.get(position).surname);

            holder.mRating.setRating(mValues.get(position).rating_mentor);

            holder.mCityView.setText(mValues.get(position).city);
            holder.mMateriesView.setText(mValues.get(position).materies);


            String uri = "@drawable/"+mValues.get(position).picture.substring(0, mValues.get(position).picture.lastIndexOf('.'));

            int imageResource = getResources().getIdentifier(uri, null, getPackageName());

            Drawable res = getResources().getDrawable(imageResource);

            holder.mPicture.setImageDrawable(res);

            holder.itemView.setTag(mValues.get(position));

            holder.itemView.setOnClickListener(mOnClickListener);
        }

        @Override
        public int getItemCount() {
            return mValues.size();
        }

        class ViewHolder extends RecyclerView.ViewHolder {
            final TextView mAliasView;
            final TextView mNameView;
            final TextView mSurnameView;
            final TextView mCityView;
            final TextView mMateriesView;
            final ImageView mPicture;
            final TextView mMemail;
            final RatingBar mRating;

            ViewHolder(View view) {
                super(view);
                mPicture = (ImageView) view.findViewById(R.id.imagePicture);
                mAliasView = (TextView) view.findViewById(R.id.mentor_alias);
                mNameView = (TextView) view.findViewById(R.id.name_text);
                mSurnameView = (TextView) view.findViewById(R.id.surname_text);
                mMateriesView = (TextView) view.findViewById(R.id.materies);
                mMemail = (TextView) view.findViewById(R.id.mentor_email);
                mCityView = (TextView) view.findViewById(R.id.city);
                mRating = (RatingBar) view.findViewById(R.id.ratingBar);
            }
        }
    }
}
