package edu.uoc.perezdehitajesus.uocapplication;

import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.text.BoringLayout;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.Switch;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ProfileActivity extends AppCompatActivity {

    private Switch switchMentor, switchStudent;

    ImageView imageView;

    Integer mentorChecked;
    Integer studentChecked;

    private static final int PICK_IMAGE = 100;

    private TextView profile_alias;
    private EditText profile_name, profile_pass, profile_surname, profile_email, profile_description, profile_mentoring_materies, profile_student_materies, profile_city;

    Uri imageUri;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_profile);
        imageView = findViewById(R.id.profile_picture);
        imageView.setImageResource(R.drawable.f_1);
        profile_alias = findViewById(R.id.alias);
        profile_name = findViewById(R.id.profile_name);
        profile_surname = findViewById(R.id.profile_surname);
        profile_email = findViewById(R.id.profile_email);
        profile_pass = findViewById(R.id.profile_pass);
        profile_description = findViewById(R.id.profile_description);
        switchMentor = findViewById(R.id.sw_is_mentor);
        switchStudent = findViewById(R.id.sw_is_student);

        profile_mentoring_materies = findViewById(R.id.mentoring_materies);
        profile_student_materies = findViewById(R.id.student_materies);
        profile_city = findViewById(R.id.city);

        loadDataUser();

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);

        getSupportActionBar().setTitle("Perfil");
    }

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        Intent intent = new Intent(this, HomeActivity.class);
        this.startActivity(intent);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();

        if (id == R.id.faqs) {
            Intent intent = new Intent(this, FaqsActivity.class);
            this.startActivity(intent);
            return true;
        }

        if (id == R.id.help) {
            Intent i = new Intent(Intent.ACTION_SEND);
            i.setType("message/rfc822");
            i.putExtra(Intent.EXTRA_EMAIL, new String[]{ getIntent().getStringExtra("jesusperezdehita@gmail.com")});
            i.putExtra(Intent.EXTRA_SUBJECT, "Contact Support User ID"+UserInfo.getUser_id()+" User:"+UserInfo.getUser_name()+" "+UserInfo.getUser_surname());
            i.putExtra(Intent.EXTRA_TEXT, "Introdueix la pregunta o incidència que tinguis detectat i ens posarem en seguida en contacte amb tu, gràcies.");
            try {
                startActivity(Intent.createChooser(i, "Enviant el correu..."));
            } catch (android.content.ActivityNotFoundException ex) {
                Toast.makeText(ProfileActivity.this, "No tens instal·lat cap client de correu com Gmail, etc.", Toast.LENGTH_SHORT).show();
            }
        }

        if (id == R.id.closeApp) {
            Intent intent = new Intent(this, LoginActivity.class);
            this.startActivity(intent);
            finishAffinity();
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data){
        super.onActivityResult(requestCode, resultCode, data);
        if(resultCode == RESULT_OK ){
            imageUri = data.getData();
            imageView.setMaxHeight(96);
            imageView.setMaxWidth(96);
            imageView.setImageURI(imageUri);
        }
    }

    public void loadDataUser(){
        String url = "http:jesusperezdehita.es/api/usuarios/"+UserInfo.getUser_id();

        RequestQueue queue = Volley.newRequestQueue(this);

        Log.d("Url", url);

        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        Log.d("Response Object", response);

                        try {
                            JSONArray jsonArray = new JSONArray(response);
                            JSONObject obj = jsonArray.getJSONObject(0);

                            String uri = "@drawable/" + UserInfo.getUser_avatar().substring(0, UserInfo.getUser_avatar().lastIndexOf('.'));

                            int imageResource = getResources().getIdentifier(uri, null, getPackageName());

                            Drawable res = getResources().getDrawable(imageResource);

                            imageView = findViewById(R.id.profile_picture);
                            imageView.setImageDrawable(res);

                            profile_alias.setText(obj.getString("alias"));

                            profile_name.setText(obj.getString("name"));
                            profile_surname.setText(obj.getString("surname"));
                            profile_email.setText(obj.getString("email"));
                            profile_pass.setText(obj.getString("pass"));

                            String description;
                            if (obj.getString("description") == "null") {
                                description = "";
                            }else{
                                description = obj.getString("description");
                            }
                            profile_description.setText(description);

                            String materies_mentor;
                            if (obj.getString("materies_mentor") == "null") {
                                materies_mentor = "";
                            }else{
                                materies_mentor = obj.getString("materies_mentor");
                            }
                            profile_mentoring_materies.setText(materies_mentor);

                            String materies_student;
                            if (obj.getString("materies_student") == "null") {
                                materies_student = "";
                            }else{
                                materies_student = obj.getString("materies_student");
                            }
                            profile_student_materies.setText(materies_student);

                            String city;
                            if (obj.getString("city") == "null") {
                                city = "";
                            }else{
                                city = obj.getString("city");
                            }
                            profile_city.setText(city);


                            Integer isStudent = Integer.parseInt(obj.getString("student"));

                            if(isStudent == 0){
                                switchStudent.setChecked(false);
                            }else{
                                switchStudent.setChecked(true);
                            }

                            Integer isMentor = Integer.parseInt(obj.getString("mentor"));

                            if(isMentor == 0){
                                switchMentor.setChecked(false);
                            }else{
                                switchMentor.setChecked(true);
                            }

                        } catch (JSONException e) {
                            e.printStackTrace();
                        }

                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Log.d("Error Volley","That didn't work!");
            }
        });

        queue.add(stringRequest);

    }

    public void saveProfile(View v){
        RequestQueue queue = Volley.newRequestQueue(this);

        if(switchMentor.isChecked()){
             mentorChecked = 1;
        }else{
             mentorChecked = 0;
        }

        if(switchStudent.isChecked()){
             studentChecked = 1;
        }else{
             studentChecked = 0;
        }

        final String urlUpdate = "http://jesusperezdehita.es/api/usuarios/"+UserInfo.getUser_id()+"?"
                +"name="+profile_name.getText().toString()
                +"&surname="+profile_surname.getText().toString()
                +"&email="+profile_email.getText().toString()
                +"&pass="+profile_pass.getText().toString()
                +"&description="+profile_description.getText().toString()
                +"&mentor="+mentorChecked
                +"&student="+studentChecked
                +"&avatar="+UserInfo.getUser_avatar()
                +"&city="+profile_city.getText().toString()
                +"&materies_mentor="+profile_mentoring_materies.getText().toString()
                +"&materies_student="+profile_student_materies.getText().toString();

        if(isCorrectEmail(profile_email.getText().toString())){
            StringRequest stringRequest = new StringRequest(Request.Method.PUT, urlUpdate,
                    new Response.Listener<String>() {
                        @Override
                        public void onResponse(String response) {
                            Log.d("Update", urlUpdate);
                            onSuccessUpdate();
                        }
                    }, new Response.ErrorListener() {
                @Override
                public void onErrorResponse(VolleyError error) {
                    Log.d("Error Volley", "That didn't work!");
                }
            });
            queue.add(stringRequest);
        }else{
            Context context = getApplicationContext();
            CharSequence text = "El format del email no es correcte.";
            int duration = Toast.LENGTH_SHORT;
            Toast toast = Toast.makeText(context, text, duration);
            toast.show();
        }
    }
    public Boolean isCorrectEmail(String email){
        String expression = "^[\\w\\.-]+@([\\w\\-]+\\.)+[A-Z]{2,4}$";
        Pattern pattern = Pattern.compile(expression, Pattern.CASE_INSENSITIVE);
        Matcher matcher = pattern.matcher(email);
        return matcher.matches();
    }
    public void onSuccessUpdate(){
        startActivity(new Intent(this, ProfileActivity.class));
    }

    public void onSelectAvatar(View v){
        startActivity(new Intent(this, AvatarActivity.class));
    }

}
