package edu.uoc.perezdehitajesus.uocapplication;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.app.Activity;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.Switch;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class RegisterActivity extends AppCompatActivity {

    private Switch switchMentor, switchStudent;

    Integer mentorChecked;
    Integer studentChecked;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_register);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);
        getSupportActionBar().setTitle("Registrar-se");

        switchMentor = (Switch) findViewById(R.id.sw_is_mentor);
        switchStudent = (Switch) findViewById(R.id.sw_is_student);
    }


    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();

        if (id == R.id.faqs) {
            Intent intent = new Intent(this, FaqsActivity.class);
            this.startActivity(intent);
            return true;
        }

        if (id == R.id.help) {
            Intent i = new Intent(Intent.ACTION_SEND);
            i.setType("message/rfc822");
            i.putExtra(Intent.EXTRA_EMAIL, new String[]{ getIntent().getStringExtra("jesusperezdehita@gmail.com")});
            i.putExtra(Intent.EXTRA_SUBJECT, "Contact Support User ID"+UserInfo.getUser_id()+" User:"+UserInfo.getUser_name()+" "+UserInfo.getUser_surname());
            i.putExtra(Intent.EXTRA_TEXT, "Introdueix la pregunta o incidència que tinguis detectat i ens posarem en seguida en contacte amb tu, gràcies.");
            try {
                startActivity(Intent.createChooser(i, "Enviant el correu..."));
            } catch (android.content.ActivityNotFoundException ex) {
                Toast.makeText(RegisterActivity.this, "No tens instal·lat cap client de correu com Gmail, etc.", Toast.LENGTH_SHORT).show();
            }
        }

        if (id == R.id.closeApp) {
            Intent intent = new Intent(this, LoginActivity.class);
            this.startActivity(intent);
            finishAffinity();
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    public void goToMainLayout(final View v) {

        if(switchMentor.isChecked()){
            mentorChecked = 1;
        }else{
            mentorChecked = 0;
        }

        if(switchStudent.isChecked()){
            studentChecked = 1;
        }else{
            studentChecked = 0;
        }

        EditText register_alias = (EditText)findViewById(R.id.register_alias);
        EditText register_name = (EditText)findViewById(R.id.register_name);
        EditText register_surname = (EditText)findViewById(R.id.register_surname);
        EditText register_email = (EditText)findViewById(R.id.register_email);
        EditText register_password = (EditText)findViewById(R.id.register_password);

        final String alias = register_alias.getText().toString();
        final String name = register_name.getText().toString();
        final String surname = register_surname.getText().toString();
        final String email = register_email.getText().toString();
        final String pass = register_password.getText().toString();

        final String url = "http:jesusperezdehita.es/api/usuarios?alias="+alias+"&name="+name+"&surname="+surname+"&email="+email+"&pass="+pass+"&mentor="+mentorChecked+"&student="+studentChecked;


        if(isCorrectEmail(email)){
            // Instantiate the RequestQueue.
            RequestQueue queue = Volley.newRequestQueue(this);

            // Request a string response from the provided URL.
            StringRequest stringRequest = new StringRequest(Request.Method.POST, url,
                    new Response.Listener<String>() {
                        @Override
                        public void onResponse(String response) {
                            try {
                                JSONArray jsonArray = new JSONArray(response);
                                JSONObject obj = jsonArray.getJSONObject(0);
                                Log.d("url string", url);
                                Log.d("user alias", obj.getString("status"));
                                String status =  obj.getString("status");
                                //Similarly do it for others as well
                                if(status.equals("true")) {
                                    UserInfo.setUser_name(name);
                                    UserInfo.setUser_pass(pass);
                                    onsuccesRegister();
                                }else{
                                    Context context = getApplicationContext();
                                    CharSequence text = obj.getString("status");
                                    int duration = Toast.LENGTH_SHORT;
                                    Toast toast = Toast.makeText(context, text, duration);
                                    toast.show();
                                }

                            } catch (JSONException e) {
                                e.printStackTrace();
                                Context context = getApplicationContext();
                                CharSequence text = e.toString();
                                int duration = Toast.LENGTH_SHORT;
                                Toast toast = Toast.makeText(context, text, duration);
                                toast.show();
                            }

                        }
                    }, new Response.ErrorListener() {
                @Override
                public void onErrorResponse(VolleyError error) {
                    Log.d("Error Volley","That didn't work!");
                }
            });

            // Add the request to the RequestQueue.
            queue.add(stringRequest);
        }else{
            Context context = getApplicationContext();
            CharSequence text = "El format del email no es correcte.";
            int duration = Toast.LENGTH_SHORT;
            Toast toast = Toast.makeText(context, text, duration);
            toast.show();
        }
    }

    public Boolean isCorrectEmail(String email){
        String expression = "^[\\w\\.-]+@([\\w\\-]+\\.)+[A-Z]{2,4}$";
        Pattern pattern = Pattern.compile(expression, Pattern.CASE_INSENSITIVE);
        Matcher matcher = pattern.matcher(email);
        return matcher.matches();
    }

    public void onsuccesRegister(){ startActivity(new Intent(this, LoginActivity.class)); }

}
