package edu.uoc.perezdehitajesus.uocapplication;

import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class UserSelected extends AppCompatActivity {

    public Intent intent;

    public Integer ratingUSer;

    public String user_type, user_id;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_user_selected);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        Intent myIntent = getIntent(); // gets the previously created intent

        user_type = myIntent.getStringExtra("user_type");
        user_id = myIntent.getStringExtra("id");
        String name = myIntent.getStringExtra("name");
        String surname = myIntent.getStringExtra("surname");

        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);


        TextView userName = findViewById(R.id.user_name);
        userName.setText(name);

        TextView userSurname = findViewById(R.id.user_surname);
        userSurname.setText(surname);


        if(user_type.equals("student")){
            getUserDataStudent(user_id);
        }else{
            getUserDataMentor(user_id);
        }

        intent = myIntent;
    }

    public void getUserDataStudent(String id){
        String url = "http://jesusperezdehita.es/api/usuarios/"+id;

        RequestQueue queue = Volley.newRequestQueue(this);

        Log.d("Url", url);

        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        Log.d("Response Object", response);

                        try {
                            JSONArray jsonArray = new JSONArray(response);
                            JSONObject obj = jsonArray.getJSONObject(0);

                            Integer ratingUSer = obj.getInt("rating_student");

                            Log.d("Rating ", ratingUSer.toString());
                            RatingBar ratingBar = findViewById(R.id.ratingBar);
                            ratingBar.setRating(ratingUSer);
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }

                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Log.d("Error Volley","That didn't work!");
            }
        });

        queue.add(stringRequest);
    }

    public void getUserDataMentor(String id){
        String url = "http://jesusperezdehita.es/api/usuarios/"+id;

        RequestQueue queue = Volley.newRequestQueue(this);

        Log.d("Url", url);

        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        Log.d("Response Object", response);

                        try {
                            JSONArray jsonArray = new JSONArray(response);
                            JSONObject obj = jsonArray.getJSONObject(0);

                            Integer ratingUSer = obj.getInt("rating_mentor");

                            Log.d("Rating ", ratingUSer.toString());
                            RatingBar ratingBar = findViewById(R.id.ratingBar);
                            ratingBar.setRating(ratingUSer);
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }

                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Log.d("Error Volley","That didn't work!");
            }
        });

        queue.add(stringRequest);

    }

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();

        if (id == R.id.faqs) {
            Intent intent = new Intent(this, FaqsActivity.class);
            this.startActivity(intent);
            return true;
        }

        if (id == R.id.help) {
            Intent i = new Intent(Intent.ACTION_SEND);
            i.setType("message/rfc822");
            i.putExtra(Intent.EXTRA_EMAIL, new String[]{ getIntent().getStringExtra("jesusperezdehita@gmail.com")});
            i.putExtra(Intent.EXTRA_SUBJECT, "Contact Support User ID"+UserInfo.getUser_id()+" User:"+UserInfo.getUser_name()+" "+UserInfo.getUser_surname());
            i.putExtra(Intent.EXTRA_TEXT, "Introdueix la pregunta o incidència que tinguis detectat i ens posarem en seguida en contacte amb tu, gràcies.");
            try {
                startActivity(Intent.createChooser(i, "Enviant el correu..."));
            } catch (android.content.ActivityNotFoundException ex) {
                Toast.makeText(UserSelected.this, "No tens instal·lat cap client de correu com Gmail, etc.", Toast.LENGTH_SHORT).show();
            }
        }

        if (id == R.id.closeApp) {
            Intent intent = new Intent(this, LoginActivity.class);
            this.startActivity(intent);
            finishAffinity();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    public void sendRating(View v) {

        RatingBar rating = findViewById(R.id.ratingBar);

        String url = "http://jesusperezdehita.es/api/rating/"+user_id+"?user_type="+user_type+"&rating="+Math.round(rating.getRating());

        RequestQueue queue = Volley.newRequestQueue(this);

        Log.d("Url", url);

        StringRequest stringRequest = new StringRequest(Request.Method.PUT, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        Log.d("Response Object", response);

                        try {
                            JSONArray jsonArray = new JSONArray(response);
                            JSONObject obj = jsonArray.getJSONObject(0);

                            if(user_type.equals("student")){
                                Integer ratingUSer = obj.getInt("rating_student");
                            }else{
                                Integer ratingUSer = obj.getInt("rating_mentor");
                            }
                            Log.d("Rating ", ratingUSer.toString());
                            RatingBar ratingBar = findViewById(R.id.ratingBar);
                            ratingBar.setRating(ratingUSer);
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }

                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Log.d("Error Volley","That didn't work!");
            }
        });

        queue.add(stringRequest);
        onBackPressed();
    }
}

